pub async fn docs_in_queue(__arg0: DbState) -> ApiResult<Json<DocQueueResponse>>Expand description
Get documentation build queue
Returns the list of crates currently in the documentation build queue.
pub async fn docs_in_queue(__arg0: DbState) -> ApiResult<Json<DocQueueResponse>>Get documentation build queue
Returns the list of crates currently in the documentation build queue.